module Nri.Ui.Sprite.V1 exposing
    ( Sprite, attach
    , SpriteId, use, spriteIdToString
    , bold, italic, underline, list, link, undo, redo
    )

{-|

@docs Sprite, attach
@docs SpriteId, use, spriteIdToString
@docs bold, italic, underline, list, link, undo, redo

-}

import Accessibility.Styled as Html exposing (Html)
import Html.Styled.Attributes
import Svg.Styled as Svg exposing (Svg)
import Svg.Styled.Attributes as Attributes


{-| -}
type Sprite
    = Sprite { id : SpriteId, svg : Svg Never }


toSprite : SpriteId -> Svg Never -> Sprite
toSprite id_ svg =
    Sprite { id = id_, svg = svg }


{-| -}
type SpriteId
    = SpriteId String


{-| -}
spriteIdToString : SpriteId -> String
spriteIdToString (SpriteId id_) =
    id_


{-| Sprites _must_ be attached to the page for them to be usable!

If your icons are missing, please make sure you're using this HTML in your view!

-}
attach : Html Never
attach =
    Html.div [ Html.Styled.Attributes.style "display" "none" ]
        (List.map addSprite allSprites)


addSprite : Sprite -> Svg Never
addSprite (Sprite sprite) =
    Svg.svg []
        [ Svg.symbol [ Attributes.id (spriteIdToString sprite.id) ]
            [ sprite.svg
            ]
        ]


{-| -}
use : SpriteId -> Svg.Svg msg
use spriteId =
    Svg.use [ Attributes.xlinkHref ("#" ++ spriteIdToString spriteId) ] []


{-|

    svg [] [ Sprite.use Sprite.bold ]

-}
bold : SpriteId
bold =
    SpriteId "icon-bold"


{-| -}
italic : SpriteId
italic =
    SpriteId "icon-italic"


{-| -}
underline : SpriteId
underline =
    SpriteId "icon-underline"


{-| -}
list : SpriteId
list =
    SpriteId "icon-list"


{-| -}
link : SpriteId
link =
    SpriteId "icon-link"


{-| -}
undo : SpriteId
undo =
    SpriteId "icon-undo"


{-| -}
redo : SpriteId
redo =
    SpriteId "icon-redo"


allSprites : List Sprite
allSprites =
    [ toSprite bold <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 13.6 13.9"
            ]
            [ Svg.path [ Attributes.d "M12.2,7.5c0.4,0.3,0.8,0.6,1,1.1s0.4,0.9,0.4,1.5c0,0.7-0.1,1.3-0.4,1.8s-0.7,0.9-1.3,1.1c-0.6,0.3-1.3,0.5-2,0.6 s-1.7,0.2-2.7,0.2H0v-0.8c0.2,0,0.5,0,0.8-0.1s0.5-0.1,0.6-0.1c0.2-0.1,0.4-0.2,0.5-0.4S2,12.1,2,11.9V2.1c0-0.2,0-0.4-0.1-0.6 S1.7,1.2,1.4,1.1C1.2,1,1,0.9,0.7,0.9S0.2,0.8,0,0.8V0h7.5c1.9,0,3.3,0.3,4.1,0.8s1.3,1.3,1.3,2.3c0,0.5-0.1,0.9-0.3,1.2 S12.1,5,11.8,5.2c-0.3,0.2-0.7,0.4-1.1,0.6S9.7,6.2,9.2,6.3v0.2c0.5,0.1,1,0.2,1.6,0.3C11.4,7,11.8,7.2,12.2,7.5z M9.1,3.3 c0-0.8-0.2-1.4-0.6-1.8S7.4,0.9,6.5,0.9c-0.1,0-0.3,0-0.5,0s-0.4,0-0.5,0v5.1H6c1.1,0,1.8-0.2,2.3-0.7S9.1,4.2,9.1,3.3z M9.8,10 c0-1-0.3-1.7-0.9-2.2C8.3,7.2,7.5,7,6.4,7C6.3,7,6.2,7,6,7S5.6,7,5.5,7v5.1c0.1,0.2,0.2,0.4,0.5,0.6C6.4,12.9,6.7,13,7.2,13 c0.8,0,1.4-0.3,1.9-0.8C9.5,11.7,9.8,10.9,9.8,10z" ] []
            ]
    , toSprite italic <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 9.5 13.9"
            ]
            [ Svg.path [ Attributes.d "M9.5,0L9.3,0.6c-0.2,0-0.5,0-0.8,0.1C8.2,0.8,7.9,0.8,7.8,0.9C7.5,1,7.3,1.1,7.2,1.3S7,1.6,7,1.8L4.6,12c0,0,0,0.1,0,0.2\n    c0,0.1,0,0.1,0,0.2c0,0.2,0,0.3,0.1,0.4c0.1,0.1,0.2,0.2,0.4,0.3c0.1,0,0.3,0.1,0.6,0.2s0.6,0.1,0.7,0.1l-0.1,0.6H0l0.1-0.6\n    c0.2,0,0.4,0,0.8-0.1s0.6-0.1,0.7-0.1c0.3-0.1,0.4-0.2,0.6-0.4s0.2-0.4,0.3-0.6L4.8,1.9c0-0.1,0-0.1,0-0.2c0-0.1,0-0.1,0-0.2\n    c0-0.1,0-0.2-0.1-0.3C4.7,1.2,4.6,1.1,4.4,1C4.3,0.9,4,0.8,3.7,0.8S3.2,0.7,3.1,0.6L3.2,0H9.5z" ] [] ]
    , toSprite underline <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 17 19"
            ]
            [ Svg.rect [ Attributes.x "2", Attributes.y "17", Attributes.width "14.3", Attributes.height "1.4" ] []
            , Svg.path [ Attributes.d "M16.3,0.754320988 C16.1130306,0.773662648 15.8438632,0.817180731 15.4924897,0.884876543 C15.1411162,0.952572355 14.8461603,1.07023236 14.6076132,1.23786008 C14.3626188,1.39904059 14.1901583,1.68916114 14.0902263,2.10823045 C13.9902944,2.52729976 13.9403292,3.1558943 13.9403292,3.99403292 L13.9403292,9.10020576 C13.9403292,10.6024081 13.4310065,11.8112437 12.4123457,12.726749 C11.3936849,13.6422542 10.0462361,14.1 8.36995885,14.1 C6.41645114,14.1 4.90460069,13.658372 3.83436214,12.7751029 C2.76412359,11.8918337 2.22901235,10.6604331 2.22901235,9.0808642 L2.22901235,2.05987654 C2.22901235,1.83422384 2.18549426,1.64081013 2.09845679,1.47962963 C2.01141932,1.31844913 1.84540589,1.17338885 1.60041152,1.04444444 C1.4327838,0.960630582 1.22647585,0.892935786 0.981481481,0.841358025 C0.736487115,0.789780263 0.536626288,0.754321084 0.381893004,0.734979424 L0.381893004,0 L7.57695473,0 L7.57695473,0.734979424 C7.37064369,0.747873864 7.16111217,0.772050577 6.94835391,0.807510288 C6.73559564,0.842969999 6.51961701,0.896158767 6.30041152,0.967078189 C6.05541716,1.04444483 5.89101551,1.1733873 5.80720165,1.35390947 C5.72338778,1.53443163 5.68148148,1.73751602 5.68148148,1.96316872 L5.68148148,8.88744856 C5.68148148,10.247812 5.98127272,11.2374455 6.5808642,11.8563786 C7.18045567,12.4753117 8.05081734,12.7847737 9.19197531,12.7847737 C10.3137916,12.7847737 11.193824,12.4430761 11.8320988,11.7596708 C12.4703736,11.0762654 12.7895062,10.0705142 12.7895062,8.74238683 L12.7895062,4.09074074 C12.7895062,3.26549656 12.7330938,2.64818449 12.6202675,2.23878601 C12.5074411,1.82938753 12.3349806,1.53443163 12.1028807,1.35390947 C11.9352529,1.21207062 11.6435206,1.08312815 11.2276749,0.967078189 C10.8118292,0.851028226 10.5200969,0.780109868 10.3524691,0.754320988 L10.3524691,0 L16.3,0 L16.3,0.754320988 Z" ] []
            ]
    , toSprite list <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 16 12.6"
            ]
            [ Svg.path [ Attributes.d "M1.7,3.4C0.8,3.4,0,2.7,0,1.7S0.8,0,1.7,0s1.7,0.8,1.7,1.7S2.7,3.4,1.7,3.4z M1.7,8C0.8,8,0,7.2,0,6.3s0.8-1.7,1.7-1.7\n    s1.7,0.8,1.7,1.7S2.7,8,1.7,8z M1.7,12.6c-0.9,0-1.7-0.8-1.7-1.7s0.8-1.7,1.7-1.7s1.7,0.8,1.7,1.7S2.7,12.6,1.7,12.6z M16,2.6\n    c0,0.2-0.1,0.3-0.3,0.3H4.9c-0.2,0-0.3-0.1-0.3-0.3V0.9c0-0.2,0.1-0.3,0.3-0.3h10.9c0.2,0,0.3,0.1,0.3,0.3V2.6z M16,7.1\n    c0,0.2-0.1,0.3-0.3,0.3H4.9c-0.2,0-0.3-0.1-0.3-0.3V5.4c0-0.2,0.1-0.3,0.3-0.3h10.9c0.2,0,0.3,0.1,0.3,0.3V7.1z M16,11.7\n    c0,0.2-0.1,0.3-0.3,0.3H4.9c-0.2,0-0.3-0.1-0.3-0.3V10c0-0.2,0.1-0.3,0.3-0.3h10.9c0.2,0,0.3,0.1,0.3,0.3V11.7z" ] [] ]
    , toSprite link <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 20 20"
            ]
            [ Svg.path [ Attributes.d "M9.36117647,7.80088235 C9.46457647,7.58718824 9.60244412,7.39188235 9.77017647,7.22414706 L9.96778824,7.02653529 L9.73800882,7.25631471 C9.58405588,7.41716176 9.45767941,7.60099118 9.36117647,7.80090294 L9.36117647,7.80088235 Z" ] []
            , Svg.path [ Attributes.d "M11.8544118,14.4002941 L7.79205882,18.4626471 C6.66844118,19.5495 5.05538235,19.9631176 3.54794118,19.5506471 C2.03944118,19.1382059 0.861823529,17.9605882 0.449411765,16.4521176 C0.0369705882,14.9447647 0.450560588,13.3318235 1.53741176,12.208 L5.59976471,8.14564706 C5.81001176,7.93425 6.04094118,7.74467647 6.28911765,7.58038235 C6.09265588,8.43170588 6.11793235,9.3175 6.36264706,10.1562059 C6.39941176,10.2756912 6.43847353,10.3859853 6.47983529,10.5100588 L3.16189412,13.8327059 C2.35307059,14.6656471 2.36342353,15.9949412 3.18372324,16.8165294 C4.00519382,17.6368529 5.33445853,17.6471765 6.16754676,16.8383585 L10.2298997,12.7760056 C10.7468997,12.2590056 10.9617526,11.5122115 10.7974585,10.7998879 C10.7549497,10.6137674 10.6894615,10.434535 10.5998468,10.2667997 C10.5492968,10.1737379 10.4918497,10.0852732 10.4275115,10.0002556 C10.2632203,9.80379382 10.1092762,9.59813794 9.96795265,9.38443206 C9.83582912,9.11329088 9.79102324,8.80884382 9.83927618,8.51125559 C9.88523206,8.220585 10.0219497,7.95175559 10.2298938,7.743785 L10.6894526,7.30490265 C11.5695115,7.73804971 12.2806879,8.45034382 12.7115115,9.33154971 C12.7367874,9.38899382 12.7666585,9.44873794 12.791935,9.50618206 C12.8172106,9.56362618 12.8195085,9.57281735 12.8332938,9.607285 C12.8470809,9.64175265 12.8838468,9.73136735 12.9068232,9.80029971 C12.9298015,9.869235 12.9596732,9.95654971 12.9826497,10.0300791 C13.2514909,10.9572262 13.2112791,11.9475791 12.8677615,12.8494615 C12.8126144,12.9976703 12.7482762,13.1435791 12.6747468,13.2837556 C12.6598112,13.3170732 12.6414291,13.3492438 12.6218968,13.3802644 C12.5943232,13.4342615 12.5633026,13.4871115 12.529985,13.5388115 C12.5322829,13.5445559 12.5322829,13.5514494 12.529985,13.5571938 C12.4886262,13.6307232 12.4426703,13.6996585 12.3944144,13.7708879 C12.2347174,13.9972203 12.0543556,14.2086232 11.8544438,14.4004762 L11.8544118,14.4002941 Z" ] []
            , Svg.path [ Attributes.d "M18.4626471,1.53735294 C17.632,0.709 16.5072353,0.243705882 15.3341176,0.243705882 C14.161,0.243705882 13.0363235,0.709 12.2055882,1.53735294 L8.14529412,5.59970588 C7.56279412,6.18564706 7.15494118,6.92208824 6.96652941,7.72747059 C6.95274265,7.79180882 6.93895588,7.85614706 6.92746765,7.92048529 C6.91597853,7.98482353 6.90678735,8.03767353 6.89989412,8.09511765 C6.89759618,8.11005324 6.89759618,8.12613824 6.89989412,8.14107353 C6.89989412,8.18932647 6.88610706,8.23987941 6.88380941,8.28813235 C6.82636529,8.84763235 6.87921382,9.41404412 7.03776235,9.95404412 C7.05384676,10.0137853 7.07223,10.0712324 7.09290941,10.1286765 C7.11358941,10.1861206 7.12278,10.2182912 7.13886529,10.2619471 L7.15724765,10.3125 C7.55707118,11.3534118 8.33715941,12.2047353 9.34015941,12.6930294 L9.79971824,12.2334706 C10.0674124,11.9669265 10.2144829,11.6027353 10.2087182,11.2247353 C10.2041224,10.8479118 10.0455741,10.4882941 9.76983588,10.2297941 C9.37001235,9.83226471 9.14598294,9.29114706 9.14598294,8.72702941 C9.14598294,8.16291176 9.37001824,7.62179412 9.76983588,7.22426471 L13.8321888,3.16191176 C14.66513,2.35308824 15.9944241,2.36344118 16.8160124,3.18374088 C17.6363359,4.00521147 17.6466594,5.33447618 16.8378415,6.16756441 L13.5175474,9.48785853 C13.5175474,9.51543206 13.5359297,9.54530265 13.5474179,9.57287618 C13.5772885,9.66019382 13.6071591,9.75210559 13.6324356,9.84631441 C13.8748532,10.6838732 13.9001297,11.5696674 13.705965,12.4198438 C13.9541268,12.2555526 14.1850532,12.0659909 14.3953179,11.8545791 L18.4623768,7.794285 C19.2907297,6.96363794 19.7560238,5.83887324 19.7560238,4.66575559 C19.7560238,3.49263794 19.2907297,2.36796147 18.4623768,1.53722618 L18.4626471,1.53735294 Z" ] []
            , Svg.path [ Attributes.d "M9.20029412,9.19588235 C9.15318824,8.98448529 9.13940294,8.76620588 9.15893529,8.55020588 C9.14055294,8.7662 9.15548853,8.98335294 9.20029412,9.19588235 Z" ] []
            ]
    , toSprite undo <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 18 8"
            ]
            [ Svg.path [ Attributes.d "M3.16 3.168C4.83 1.76 6.938.879 9.22.879c4.126 0 7.55 2.64 8.78 6.336l-2.107.705c-.879-2.816-3.513-4.84-6.674-4.84a6.877 6.877 0 0 0-4.478 1.672L7.902 7.92H0V0l3.16 3.168z" ] [] ]
    , toSprite redo <|
        Svg.svg
            [ Attributes.width "100%"
            , Attributes.height "100%"
            , Attributes.fill "currentcolor"
            , Attributes.viewBox "0 0 18 8"
            ]
            [ Svg.path [ Attributes.transform "scale(-1,1) translate(-18,0)", Attributes.d "M3.16 3.168C4.83 1.76 6.938.879 9.22.879c4.126 0 7.55 2.64 8.78 6.336l-2.107.705c-.879-2.816-3.513-4.84-6.674-4.84a6.877 6.877 0 0 0-4.478 1.672L7.902 7.92H0V0l3.16 3.168z" ] [] ]
    ]
